==> haskell-tasty-sugar-2.2.2.1-75-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-L8ivGoxZPgoCHqu7D7yARm-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-L8ivGoxZPgoCHqu7D7yARm-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  0d5cc275d9b9d076abf11794bfcdf02a
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-L8ivGoxZPgoCHqu7D7yARm-tasty-sugar-internal

depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p filepath-1.4.300.1
    kvitable-1.1.1.0-8JvYnGLkLM01CcyWRVV4li
    logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-EDu68ChlZ4hFd2NMlGThhJ
key:                  tasty-sugar-2.2.2.1-EDu68ChlZ4hFd2NMlGThhJ
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  8f507dae47b7b51240cd91a97204e4d1
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-EDu68ChlZ4hFd2NMlGThhJ
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p filepath-1.4.300.1
    logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    tasty-sugar-2.2.2.1-L8ivGoxZPgoCHqu7D7yARm-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.2.2.1-78-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-IgYdZpChz3eAn0lU65j4CI-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-IgYdZpChz3eAn0lU65j4CI-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  7e9a1260e14b820a559c88300ad503cc
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-IgYdZpChz3eAn0lU65j4CI-tasty-sugar-internal

depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-DJb107RJEQaGwHzKM8fFFN filepath-1.4.300.1
    kvitable-1.1.1.0-kRjbNKUY1kCOcc65FL6cH
    logict-0.8.2.0-CetHJCqKZCxLCYt6b5EYXS
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-KDJAiZAHo4i1mpCdBbPsy8
key:                  tasty-sugar-2.2.2.1-KDJAiZAHo4i1mpCdBbPsy8
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  0b7adf9964fbdbd22bda92f48dcb9d32
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-KDJAiZAHo4i1mpCdBbPsy8
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-DJb107RJEQaGwHzKM8fFFN filepath-1.4.300.1
    logict-0.8.2.0-CetHJCqKZCxLCYt6b5EYXS
    optparse-applicative-0.18.1.0-EZi3UgmTFLmKW119EQEIXK
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w
    tasty-1.5.2-9G3Kf1f0lGYDWNQy5BbNrN
    tasty-sugar-2.2.2.1-IgYdZpChz3eAn0lU65j4CI-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
